@@ -216,6 +216,14 @@ pango_win32_get_debug_flag (void)
   return _pango_win32_debug;
 }
 
+static PangoFontFace *
+pango_win32_font_get_face (PangoFont *font)
+{
+  PangoWin32Font *win32font = (PangoWin32Font *)font;
+
+  return PANGO_FONT_FACE (win32font->win32face);
+}
+
 static void
 _pango_win32_font_class_init (PangoWin32FontClass *class)
 {
@@ -240,6 +248,7 @@ _pango_win32_font_class_init (PangoWin32FontClass *class)
 
   pclass = g_type_class_get_private ((GTypeClass *) class, PANGO_TYPE_FONT);
   pclass->is_hinted = pango_win32_font_is_hinted;
+  pclass->get_face = pango_win32_font_get_face;
 
   _pango_win32_get_display_dc ();
 }
@@ -873,8 +882,8 @@ pango_win32_font_finalize (GObject *object)
   g_slist_foreach (win32font->metrics_by_lang, (GFunc)free_metrics_info, NULL);
   g_slist_free (win32font->metrics_by_lang);
 
-  if (win32font->win32face)
-    pango_win32_font_entry_remove (win32font->win32face, PANGO_FONT (win32font));
+  pango_win32_font_entry_remove (win32font->win32face, PANGO_FONT (win32font));
+  g_object_unref (win32font->win32face);
 
   g_hash_table_destroy (win32font->glyph_info);
 
@@ -894,7 +903,7 @@ pango_win32_font_describe (PangoFont *font)
   int size;
 
   desc = pango_font_description_copy (win32font->win32face->description);
-  size = (int) (0.5 + win32font->size * PANGO_WIN32_FONT_MAP (win32font->fontmap)->resolution / PANGO_SCALE);
+  size = (int) (0.5 + win32font->size * 72.0 / PANGO_WIN32_FONT_MAP (win32font->fontmap)->dpi);
   pango_font_description_set_size (desc, size);
 
   if (win32font->variations)
@@ -920,7 +929,7 @@ pango_win32_font_describe_absolute (PangoFont *font)
 
 static PangoCoverage *
 pango_win32_font_get_coverage (PangoFont     *font,
-			       PangoLanguage *lang G_GNUC_UNUSED)
+                               PangoLanguage *lang G_GNUC_UNUSED)
 {
   PangoWin32Face *win32face = ((PangoWin32Font *)font)->win32face;
 
@@ -930,7 +939,6 @@ pango_win32_font_get_coverage (PangoFont     *font,
       hb_font_t *hb_font = pango_font_get_hb_font (font);
       hb_face_t *hb_face = hb_font_get_face (hb_font);
       hb_set_t *chars = hb_set_create ();
-      hb_codepoint_t ch = HB_SET_VALUE_INVALID;
 
       hb_face_collect_unicodes (hb_face, chars);
 
@@ -1365,62 +1373,3 @@ pango_win32_font_create_hb_font (PangoFont *font)
 
   return hb_font;
 }
-
-gpointer
-_pango_win32_copy_cmap (gpointer cmap, guint16 cmap_format)
-{
-  if (!cmap)
-    return NULL;
-
-  if (cmap_format == 12)
-    {
-      struct format_12_cmap *new_table;
-      struct format_12_cmap *old_table;
-      guint32 *tbl, *tbl_end;
-
-      old_table = (struct format_12_cmap *) cmap;
-
-      new_table = g_malloc (old_table->length);
-      memcpy (old_table, new_table, sizeof (struct format_12_cmap));
-
-      tbl_end = (guint32 *) ((char *) new_table + new_table->length);
-      tbl = new_table->groups;
-
-      while (tbl < tbl_end)
-        {
-          *tbl = GUINT32_FROM_BE (*tbl);
-          tbl++;
-        }
-
-      return new_table;
-    }
-  else if (cmap_format == 4)
-    {
-      struct format_4_cmap *new_table;
-      struct format_4_cmap *old_table;
-      guint16 *tbl, *tbl_end;
-
-      old_table = (struct format_4_cmap *) cmap;
-
-      new_table = g_malloc (old_table->length);
-      memcpy (old_table, new_table, sizeof (struct format_4_cmap));
-
-      tbl_end = (guint16 *)((char *) new_table + new_table->length);
-      tbl = &new_table->reserved;
-
-      while (tbl < tbl_end)
-        {
-          *tbl = GUINT16_FROM_BE (*tbl);
-          tbl++;
-        }
-
-      return new_table;
-    }
-  else
-    {
-      /* got non-null cmap but unknown format, it shouldn't happen */
-      g_assert_not_reached ();
-    }
-
-  return NULL;
-}
